==> node-assignment-04-1.0.0.tgz: package/README.md <==
# Objective
- Create and publish a simple utility package to NPM that offers array manipulation functions. This package demonstrates the understanding of setting up a package for NPM, including writing a useful README, choosing an appropriate license, understanding semantic versioning, and utilizing .npmignore.

## Instructions
### Step 1: Initialize the Package
- Setup: Initialize a new Node.js project in a clean directory.
- Use npm init to create a package.json file, filling in details like name, version, and entry point (e.g., index.js). Can be done automatically by npm init -y command.
### Step 2: Create Utility Functions
- Develop Array Utilities:
In the project, created an index.js file.
Implemented two array utility functions, such as addELements and removeElements from an Array, These functions perform actions indicated by their names and be exported from index.js.
### Step 3: Prepared for Publishing
- Documentation: Wrote README.md file explaining what this package does, how to install it, and how to use the array utilities.

- License: Choose an appropriate license for the package (e.g., MIT) by editing the package.json file, under "License" 

- Versioning: Package version follows Semantic Versioning (SemVer) in this case version 1.0.0

- .npmignore: Created a .npmignore file to exclude unnecessary files (e.g., README file) from the published package.

### Step 4: Publish Your Package
- NPM Login: Used npm login to log in to  NPM account from the command line.

- Publish: Ran npm publish to publish the package to NPM with a unique package name!

==> node-assignment-04-1.0.3.tgz: package/README.md <==
# Objective
- Create and publish a simple utility package to NPM that offers array manipulation functions. This package demonstrates the understanding of setting up a package for NPM, including writing a useful README, choosing an appropriate license, understanding semantic versioning, and utilizing .npmignore.

## Instructions
### Step 1: Initialize the Package
- Setup: Initialize a new Node.js project in a clean directory.
- Use npm init to create a package.json file, filling in details like name, version, and entry point (e.g., index.js). Can be done automatically by npm init -y command.
### Step 2: Create Utility Functions
- Develop Array Utilities:
In the project, created an index.js file.
Implemented two array utility functions, such as addELements and removeElements from an Array, These functions perform actions indicated by their names and be exported from index.js.
### Step 3: Prepared for Publishing
- Documentation: Wrote README.md file explaining what this package does, how to install it, and how to use the array utilities.

- License: Chose an appropriate license for the package (e.g., MIT) by editing "License" in package.json file. 

- Version: Package version follows Semantic Versioning (SemVer) in this case version 1.0.0

- .npmignore: Created a .npmignore file to exclude unnecessary files (e.g., README file) from the published package.

### Step 4: Publish Your Package
- NPM Login: Used npm login to log in to  NPM account from the command line.

- Publish: Ran npm publish to publish the package to NPM with a unique package name!

## nmp link: https://www.npmjs.com/package/node-assignment-04?activeTab=readme
